# coding: utf-8

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import List
from typing_extensions import Annotated
from wordlift_client.models.web_async import WebAsync

from wordlift_client.api_client import ApiClient, RequestSerialized
from wordlift_client.api_response import ApiResponse
from wordlift_client.rest import RESTResponseType


class WebAsyncsMetadataApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def get1(
        self,
        id: Annotated[StrictStr, Field(description="The Web Async id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> WebAsync:
        """Get by id

        Get a Web Async operation by its id.

        :param id: The Web Async id (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get1_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "WebAsync",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get1_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The Web Async id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[WebAsync]:
        """Get by id

        Get a Web Async operation by its id.

        :param id: The Web Async id (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get1_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "WebAsync",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get1_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The Web Async id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get by id

        Get a Web Async operation by its id.

        :param id: The Web Async id (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get1_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "WebAsync",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get1_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/webasyncs/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def list(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[WebAsync]:
        """List

        List all Web Async operations.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[WebAsync]",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def list_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[WebAsync]]:
        """List

        List all Web Async operations.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[WebAsync]",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def list_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List

        List all Web Async operations.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[WebAsync]",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/webasyncs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from wordlift_client.models.account_subscription import AccountSubscription
from wordlift_client.models.diagnostic_plugin import DiagnosticPlugin
from typing import Optional, Set
from typing_extensions import Self

class ActiveAccount(BaseModel):
    """
    An array of objects.
    """ # noqa: E501
    collection: Optional[StrictStr] = Field(default='entity', description="The collection hosting the Knowledge Graph.")
    country: Optional[StrictStr] = None
    diagnostic_plugins: Optional[List[DiagnosticPlugin]] = None
    domain_uri: Optional[StrictStr] = None
    google_search_console_site_url: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    is_wordpress: Optional[StrictBool] = None
    key: Optional[StrictStr] = None
    language: Optional[StrictStr] = None
    ng_dataset_id: Optional[StrictStr] = None
    package_type: Optional[StrictStr] = None
    subscription: Optional[AccountSubscription] = None
    subscription_id: Optional[StrictInt] = None
    total_entities: Optional[StrictInt] = None
    total_entities_with_schema_url: Optional[StrictInt] = None
    url: Optional[StrictStr] = None
    user_id: Optional[StrictInt] = None
    wp_admin: Optional[StrictStr] = None
    wp_include_exclude_default: Optional[StrictStr] = None
    wp_json: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["collection", "country", "diagnostic_plugins", "domain_uri", "google_search_console_site_url", "id", "is_wordpress", "key", "language", "ng_dataset_id", "package_type", "subscription", "subscription_id", "total_entities", "total_entities_with_schema_url", "url", "user_id", "wp_admin", "wp_include_exclude_default", "wp_json"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ActiveAccount from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in diagnostic_plugins (list)
        _items = []
        if self.diagnostic_plugins:
            for _item in self.diagnostic_plugins:
                if _item:
                    _items.append(_item.to_dict())
            _dict['diagnostic_plugins'] = _items
        # override the default output from pydantic by calling `to_dict()` of subscription
        if self.subscription:
            _dict['subscription'] = self.subscription.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ActiveAccount from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "collection": obj.get("collection") if obj.get("collection") is not None else 'entity',
            "country": obj.get("country"),
            "diagnostic_plugins": [DiagnosticPlugin.from_dict(_item) for _item in obj["diagnostic_plugins"]] if obj.get("diagnostic_plugins") is not None else None,
            "domain_uri": obj.get("domain_uri"),
            "google_search_console_site_url": obj.get("google_search_console_site_url"),
            "id": obj.get("id"),
            "is_wordpress": obj.get("is_wordpress"),
            "key": obj.get("key"),
            "language": obj.get("language"),
            "ng_dataset_id": obj.get("ng_dataset_id"),
            "package_type": obj.get("package_type"),
            "subscription": AccountSubscription.from_dict(obj["subscription"]) if obj.get("subscription") is not None else None,
            "subscription_id": obj.get("subscription_id"),
            "total_entities": obj.get("total_entities"),
            "total_entities_with_schema_url": obj.get("total_entities_with_schema_url"),
            "url": obj.get("url"),
            "user_id": obj.get("user_id"),
            "wp_admin": obj.get("wp_admin"),
            "wp_include_exclude_default": obj.get("wp_include_exclude_default"),
            "wp_json": obj.get("wp_json")
        })
        return _obj





# coding: utf-8

"""
    SEO Content Analysis API

    This API assesses the match between a URL or text content, a query, and an intent, using advanced SEO techniques.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.account_stats_api import AccountStatsApi


class TestAccountStatsApi(unittest.TestCase):
    """AccountStatsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountStatsApi()

    def tearDown(self) -> None:
        pass

    def test_get_my_stats(self) -> None:
        """Test case for get_my_stats

        Get my Account statistics
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from wordlift_client.models.filter_value import FilterValue
from typing import Optional, Set
from typing_extensions import Self

class Filter(BaseModel):
    """
    A query request filter.
    """ # noqa: E501
    filters: Optional[List[Filter]] = Field(default=None, description="Operational filters such as AND or OR.")
    key: Optional[StrictStr] = Field(default=None, description="The filter key. Key is required for the filters [EQ, NE, GT, LT, GTE, LTE, IN, NIN]")
    operator: StrictStr = Field(description="A query request filter operator.")
    value: Optional[FilterValue] = None
    value_date: Optional[datetime] = Field(default=None, description="The filter value as a date, if provided will be preferred over the `value` field.")
    __properties: ClassVar[List[str]] = ["filters", "key", "operator", "value", "value_date"]

    @field_validator('operator')
    def operator_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['EQ', 'GT', 'LT', 'NE', 'GTE', 'LTE', 'IN', 'NIN', 'AND', 'OR']):
            raise ValueError("must be one of enum values ('EQ', 'GT', 'LT', 'NE', 'GTE', 'LTE', 'IN', 'NIN', 'AND', 'OR')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Filter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in filters (list)
        _items = []
        if self.filters:
            for _item in self.filters:
                if _item:
                    _items.append(_item.to_dict())
            _dict['filters'] = _items
        # override the default output from pydantic by calling `to_dict()` of value
        if self.value:
            _dict['value'] = self.value.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Filter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "filters": [Filter.from_dict(_item) for _item in obj["filters"]] if obj.get("filters") is not None else None,
            "key": obj.get("key"),
            "operator": obj.get("operator"),
            "value": FilterValue.from_dict(obj["value"]) if obj.get("value") is not None else None,
            "value_date": obj.get("value_date")
        })
        return _obj

# TODO: Rewrite to not use raise_errors
Filter.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.o_auth2_authorized_clients_api import OAuth2AuthorizedClientsApi


class TestOAuth2AuthorizedClientsApi(unittest.TestCase):
    """OAuth2AuthorizedClientsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OAuth2AuthorizedClientsApi()

    def tearDown(self) -> None:
        pass

    def test_create_o_auth2_authorized_client(self) -> None:
        """Test case for create_o_auth2_authorized_client

        Create
        """
        pass

    def test_delete_o_auth2_authorized_client(self) -> None:
        """Test case for delete_o_auth2_authorized_client

        Delete
        """
        pass

    def test_get_o_auth2_authorized_client(self) -> None:
        """Test case for get_o_auth2_authorized_client

        Get
        """
        pass

    def test_list_o_auth2_authorized_clients(self) -> None:
        """Test case for list_o_auth2_authorized_clients

        List
        """
        pass

    def test_update_o_auth2_authorized_client(self) -> None:
        """Test case for update_o_auth2_authorized_client

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.completion_request import CompletionRequest

class TestCompletionRequest(unittest.TestCase):
    """CompletionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CompletionRequest:
        """Test CompletionRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CompletionRequest`
        """
        model = CompletionRequest()
        if include_optional:
            return CompletionRequest(
                frequency_penalty = -2,
                logit_bias = {
                    'key' : 56
                    },
                max_tokens = 1,
                min_words = 0,
                model_id = 1,
                presence_penalty = -2,
                prompt = '',
                stop = '',
                temperature = 0
            )
        else:
            return CompletionRequest(
                prompt = '',
        )
        """

    def testCompletionRequest(self):
        """Test CompletionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.82.0"

# import apis into sdk package
from wordlift_client.api.account_api import AccountApi
from wordlift_client.api.account_stats_api import AccountStatsApi
from wordlift_client.api.accounts_api import AccountsApi
from wordlift_client.api.add_ons_api import AddOnsApi
from wordlift_client.api.agent_api import AgentApi
from wordlift_client.api.analyses_api import AnalysesApi
from wordlift_client.api.analytics_imports_api import AnalyticsImportsApi
from wordlift_client.api.authors_api import AuthorsApi
from wordlift_client.api.autocomplete_api import AutocompleteApi
from wordlift_client.api.botify_crawl_imports_api import BotifyCrawlImportsApi
from wordlift_client.api.classifications_api import ClassificationsApi
from wordlift_client.api.content_expansions_api import ContentExpansionsApi
from wordlift_client.api.content_generation_completion_api import ContentGenerationCompletionApi
from wordlift_client.api.content_generation_fields_api import ContentGenerationFieldsApi
from wordlift_client.api.content_generation_models_api import ContentGenerationModelsApi
from wordlift_client.api.content_generation_presets_api import ContentGenerationPresetsApi
from wordlift_client.api.content_generation_records_api import ContentGenerationRecordsApi
from wordlift_client.api.content_generation_records_export_api import ContentGenerationRecordsExportApi
from wordlift_client.api.content_generation_renders_api import ContentGenerationRendersApi
from wordlift_client.api.content_generation_stats_api import ContentGenerationStatsApi
from wordlift_client.api.content_generation_syncs_api import ContentGenerationSyncsApi
from wordlift_client.api.content_generation_word_biases_api import ContentGenerationWordBiasesApi
from wordlift_client.api.content_generations_api import ContentGenerationsApi
from wordlift_client.api.custom_domains_api import CustomDomainsApi
from wordlift_client.api.data_uri_api import DataURIApi
from wordlift_client.api.dataset_api import DatasetApi
from wordlift_client.api.embedding_api import EmbeddingApi
from wordlift_client.api.embeddings_api import EmbeddingsApi
from wordlift_client.api.entities_api import EntitiesApi
from wordlift_client.api.entity_gaps_api import EntityGapsApi
from wordlift_client.api.fact_check_api import FactCheckApi
from wordlift_client.api.google_merchants_api import GoogleMerchantsApi
from wordlift_client.api.google_search_console_api import GoogleSearchConsoleApi
from wordlift_client.api.google_search_console_o_auth2_api import GoogleSearchConsoleOAuth2Api
from wordlift_client.api.google_search_console_searches_api import GoogleSearchConsoleSearchesApi
from wordlift_client.api.graph_ql_api import GraphQLApi
from wordlift_client.api.include_excludes_api import IncludeExcludesApi
from wordlift_client.api.inspector_api import InspectorApi
from wordlift_client.api.internal_links_api import InternalLinksApi
from wordlift_client.api.long_tails_api import LongTailsApi
from wordlift_client.api.merchant_syncs_api import MerchantSyncsApi
from wordlift_client.api.merchants_api import MerchantsApi
from wordlift_client.api.microdata_api import MicrodataApi
from wordlift_client.api.o_auth2_authorized_clients_api import OAuth2AuthorizedClientsApi
from wordlift_client.api.platform_consumptions_api import PlatformConsumptionsApi
from wordlift_client.api.platform_limits_api import PlatformLimitsApi
from wordlift_client.api.plugin_diagnostics_api import PluginDiagnosticsApi
from wordlift_client.api.plugin_events_api import PluginEventsApi
from wordlift_client.api.questions_and_answers_api import QuestionsAndAnswersApi
from wordlift_client.api.redeem_codes_api import RedeemCodesApi
from wordlift_client.api.rules_api import RulesApi
from wordlift_client.api.seo_scores_api import SEOScoresApi
from wordlift_client.api.sitemap_generator_api import SitemapGeneratorApi
from wordlift_client.api.sitemap_imports_api import SitemapImportsApi
from wordlift_client.api.summarizations_api import SummarizationsApi
from wordlift_client.api.vector_search_nodes_api import VectorSearchNodesApi
from wordlift_client.api.vector_search_queries_api import VectorSearchQueriesApi
from wordlift_client.api.vector_search_questions_api import VectorSearchQuestionsApi
from wordlift_client.api.web_asyncs_metadata_api import WebAsyncsMetadataApi
from wordlift_client.api.web_asyncs_responses_api import WebAsyncsResponsesApi

# import ApiClient
from wordlift_client.api_response import ApiResponse
from wordlift_client.api_client import ApiClient
from wordlift_client.configuration import Configuration
from wordlift_client.exceptions import OpenApiException
from wordlift_client.exceptions import ApiTypeError
from wordlift_client.exceptions import ApiValueError
from wordlift_client.exceptions import ApiKeyError
from wordlift_client.exceptions import ApiAttributeError
from wordlift_client.exceptions import ApiException

# import models into sdk package
from wordlift_client.models.account import Account
from wordlift_client.models.account_info import AccountInfo
from wordlift_client.models.account_stats import AccountStats
from wordlift_client.models.account_subscription import AccountSubscription
from wordlift_client.models.active_account import ActiveAccount
from wordlift_client.models.add_on_configuration import AddOnConfiguration
from wordlift_client.models.analyses_request import AnalysesRequest
from wordlift_client.models.analyses_response import AnalysesResponse
from wordlift_client.models.analyses_response_item import AnalysesResponseItem
from wordlift_client.models.analytics_import_request import AnalyticsImportRequest
from wordlift_client.models.anchor_text import AnchorText
from wordlift_client.models.annotation import Annotation
from wordlift_client.models.ask_request import AskRequest
from wordlift_client.models.ask_response import AskResponse
from wordlift_client.models.author_request import AuthorRequest
from wordlift_client.models.authorization import Authorization
from wordlift_client.models.authorization_status import AuthorizationStatus
from wordlift_client.models.autocomplete_result import AutocompleteResult
from wordlift_client.models.batch_request import BatchRequest
from wordlift_client.models.botify_crawl_import_request import BotifyCrawlImportRequest
from wordlift_client.models.build_authorize_uri_request import BuildAuthorizeUriRequest
from wordlift_client.models.build_authorize_uri_response import BuildAuthorizeUriResponse
from wordlift_client.models.classification_request import ClassificationRequest
from wordlift_client.models.classification_response import ClassificationResponse
from wordlift_client.models.completion_request import CompletionRequest
from wordlift_client.models.content_expansion_request import ContentExpansionRequest
from wordlift_client.models.content_expansion_response import ContentExpansionResponse
from wordlift_client.models.content_generation import ContentGeneration
from wordlift_client.models.content_generation_request import ContentGenerationRequest
from wordlift_client.models.content_generation_stats import ContentGenerationStats
from wordlift_client.models.create_embeddings_input import CreateEmbeddingsInput
from wordlift_client.models.create_seo_score200_response import CreateSEOScore200Response
from wordlift_client.models.create_seo_score_request import CreateSEOScoreRequest
from wordlift_client.models.diagnostic_plugin import DiagnosticPlugin
from wordlift_client.models.diagnostic_plugin_request import DiagnosticPluginRequest
from wordlift_client.models.domain_validation_request import DomainValidationRequest
from wordlift_client.models.duplicate_authorization_request import DuplicateAuthorizationRequest
from wordlift_client.models.embedding_request import EmbeddingRequest
from wordlift_client.models.entity import Entity
from wordlift_client.models.entity1 import Entity1
from wordlift_client.models.entity_gap_request import EntityGapRequest
from wordlift_client.models.entity_match import EntityMatch
from wordlift_client.models.entity_patch_request import EntityPatchRequest
from wordlift_client.models.event import Event
from wordlift_client.models.exchange_auth_code_request import ExchangeAuthCodeRequest
from wordlift_client.models.exchange_auth_code_response import ExchangeAuthCodeResponse
from wordlift_client.models.filter import Filter
from wordlift_client.models.filter_value import FilterValue
from wordlift_client.models.generate_sitemap200_response import GenerateSitemap200Response
from wordlift_client.models.generate_sitemap_request import GenerateSitemapRequest
from wordlift_client.models.graphql_request import GraphqlRequest
from wordlift_client.models.http_validation_error import HTTPValidationError
from wordlift_client.models.html import Html
from wordlift_client.models.image import Image
from wordlift_client.models.include_exclude import IncludeExclude
from wordlift_client.models.include_exclude_request import IncludeExcludeRequest
from wordlift_client.models.inspect_response import InspectResponse
from wordlift_client.models.internal_link import InternalLink
from wordlift_client.models.internal_link_destination import InternalLinkDestination
from wordlift_client.models.internal_link_request import InternalLinkRequest
from wordlift_client.models.internal_link_source import InternalLinkSource
from wordlift_client.models.item import Item
from wordlift_client.models.kg_embedding_request import KgEmbeddingRequest
from wordlift_client.models.level_enum import LevelEnum
from wordlift_client.models.location_inner import LocationInner
from wordlift_client.models.longtail_response import LongtailResponse
from wordlift_client.models.merchant import Merchant
from wordlift_client.models.merchant_entry import MerchantEntry
from wordlift_client.models.merchant_request import MerchantRequest
from wordlift_client.models.merchant_sync import MerchantSync
from wordlift_client.models.merchant_view import MerchantView
from wordlift_client.models.model import Model
from wordlift_client.models.model_field import ModelField
from wordlift_client.models.network_account_info import NetworkAccountInfo
from wordlift_client.models.node_request import NodeRequest
from wordlift_client.models.node_request_metadata_value import NodeRequestMetadataValue
from wordlift_client.models.o_auth2_authorized_client import OAuth2AuthorizedClient
from wordlift_client.models.o_auth2_authorized_client_request import OAuth2AuthorizedClientRequest
from wordlift_client.models.page_active_account import PageActiveAccount
from wordlift_client.models.page_add_on_configuration import PageAddOnConfiguration
from wordlift_client.models.page_content_generation import PageContentGeneration
from wordlift_client.models.page_field import PageField
from wordlift_client.models.page_merchant_entry import PageMerchantEntry
from wordlift_client.models.page_merchant_sync import PageMerchantSync
from wordlift_client.models.page_merchant_view import PageMerchantView
from wordlift_client.models.page_model import PageModel
from wordlift_client.models.page_o_auth2_authorized_client import PageOAuth2AuthorizedClient
from wordlift_client.models.page_platform_limit import PagePlatformLimit
from wordlift_client.models.page_preset import PagePreset
from wordlift_client.models.page_record import PageRecord
from wordlift_client.models.page_rule import PageRule
from wordlift_client.models.page_vector_search_query_response_item import PageVectorSearchQueryResponseItem
from wordlift_client.models.page_vector_search_question_response_item import PageVectorSearchQuestionResponseItem
from wordlift_client.models.page_website import PageWebsite
from wordlift_client.models.page_website_search import PageWebsiteSearch
from wordlift_client.models.page_with_limits import PageWithLimits
from wordlift_client.models.page_word import PageWord
from wordlift_client.models.platform_limit import PlatformLimit
from wordlift_client.models.platform_limit_request import PlatformLimitRequest
from wordlift_client.models.preset import Preset
from wordlift_client.models.problem_detail import ProblemDetail
from wordlift_client.models.project_type import ProjectType
from wordlift_client.models.properties import Properties
from wordlift_client.models.properties1 import Properties1
from wordlift_client.models.question_and_answer import QuestionAndAnswer
from wordlift_client.models.question_and_answer_request import QuestionAndAnswerRequest
from wordlift_client.models.rank_entities import RankEntities
from wordlift_client.models.record import Record
from wordlift_client.models.render_request import RenderRequest
from wordlift_client.models.request import Request
from wordlift_client.models.request1 import Request1
from wordlift_client.models.request2 import Request2
from wordlift_client.models.request3 import Request3
from wordlift_client.models.response import Response
from wordlift_client.models.response1 import Response1
from wordlift_client.models.response2 import Response2
from wordlift_client.models.rule import Rule
from wordlift_client.models.rule_request import RuleRequest
from wordlift_client.models.scope import Scope
from wordlift_client.models.sitemap_import_request import SitemapImportRequest
from wordlift_client.models.smart_content import SmartContent
from wordlift_client.models.smart_content_request import SmartContentRequest
from wordlift_client.models.submit_fact_check200_response import SubmitFactCheck200Response
from wordlift_client.models.submit_fact_check_request import SubmitFactCheckRequest
from wordlift_client.models.topic import Topic
from wordlift_client.models.update_account_request import UpdateAccountRequest
from wordlift_client.models.update_question_and_answer_request import UpdateQuestionAndAnswerRequest
from wordlift_client.models.update_record_request import UpdateRecordRequest
from wordlift_client.models.update_records_request import UpdateRecordsRequest
from wordlift_client.models.validation_error import ValidationError
from wordlift_client.models.validation_fix import ValidationFix
from wordlift_client.models.validation_result import ValidationResult
from wordlift_client.models.validation_type_enum import ValidationTypeEnum
from wordlift_client.models.vector_search_query_request import VectorSearchQueryRequest
from wordlift_client.models.vector_search_query_response_item import VectorSearchQueryResponseItem
from wordlift_client.models.vector_search_query_response_item_fields_value_inner import VectorSearchQueryResponseItemFieldsValueInner
from wordlift_client.models.vector_search_query_response_item_metadata_value import VectorSearchQueryResponseItemMetadataValue
from wordlift_client.models.vector_search_question_request import VectorSearchQuestionRequest
from wordlift_client.models.vector_search_question_response_item import VectorSearchQuestionResponseItem
from wordlift_client.models.web_async import WebAsync
from wordlift_client.models.web_page import WebPage
from wordlift_client.models.webpage_properties import WebpageProperties
from wordlift_client.models.website import Website
from wordlift_client.models.website_search import WebsiteSearch
from wordlift_client.models.what_operand_lhs import WhatOperandLhs
from wordlift_client.models.what_operator import WhatOperator
from wordlift_client.models.when_operator import WhenOperator
from wordlift_client.models.with_limits import WithLimits
from wordlift_client.models.word import Word
from wordlift_client.models.word_repetition_data import WordRepetitionData
from wordlift_client.models.word_request import WordRequest
